@@ -24,7 +24,7 @@
 
 //-----------------------------------------------------------------------------
 // name: util_math.h
-// desc: a mini-compatibility library for math functions.
+// desc: a mini-compatibility library for math functions
 //
 // author: Ge Wang (ge@ccrma.stanford.edu | gewang@cs.princeton.edu)
 //         Philip Davidson (philipd@alumni.princeton.edu)
@@ -34,6 +34,7 @@
 #define __UTIL_MATH_H__
 
 #include <math.h>
+#include "chuck_def.h" // 1.4.1.0 (ge) for t_CKINT
 
 #if defined (__cplusplus) || defined(_cplusplus)
 extern "C" {
@@ -51,18 +52,28 @@ extern "C" {
 double ck_remainder( double a, double b );
 
 
-// max for random functions
-#ifdef __PLATFORM_WIN32__
-#define CK_RANDOM_MAX RAND_MAX
-#else
-#define CK_RANDOM_MAX 0x7fffffff
-#endif
-
 // chuck random wrapper
-long ck_random();
+t_CKINT ck_random();
 // chuck srandom wrapper
 void ck_srandom( unsigned seed );
 
+//-----------------------------------------------------------------------------
+#ifndef __OLDSCHOOL_RANDOM__
+//-----------------------------------------------------------------------------
+#define CK_RANDOM_MAX 0x7fffffff
+//-----------------------------------------------------------------------------
+#else // __OLDSCHOOL_RANDOM__ (enable only for compatibility pre-c++11)
+//-----------------------------------------------------------------------------
+#ifdef __PLATFORM_WIN32__
+  #define CK_RANDOM_MAX RAND_MAX
+#else
+  #define CK_RANDOM_MAX 0x7fffffff
+#endif
+//-----------------------------------------------------------------------------
+#endif // __OLDSCHOOL_RANDOM__
+//-----------------------------------------------------------------------------
+
+
 // mtof
 double mtof( double f );
 // ftom
